//--
//--	animwind.h
//--
//--	TBitmapAnimatorWindow Class Header File
//--
//-- This class provides basic animation functionality encased in
//-- a TFrameWindow.  To get specific game functionality, derive
//-- a class from it.  Override the TFrameWindow functions you want
//-- to implement.  You need to have a function for initializing the
//-- palette.  It is called from the SetupWindow function.


#if !defined(__ULU_ANIMATE_H)
#define __ULU_ANIMATE_H

#include <owl\module.h>
#include <owl\point.h>
#include <owl\dc.h>
#include <owl\gdiobjec.h>
#include <owl\window.h>

#pragma hdrstop
#include "palette.h"
#include "buffer.h"

// the following determine the size of the CLIENT area.
#define CLIENT_SCREEN_WIDTH (450)
#define CLIENT_SCREEN_HEIGHT (350)

class TBitmapAnimatorWindow : public TFrameWindow
{
	public:
		TBitmapAnimatorWindow(TWindow *pParWnd,
										const char far * = 0);
		virtual ~TBitmapAnimatorWindow();

	protected:

		TBuffer *buffer;
		TClientDC *pClientDC;
		TIdentityPalette *pPalette;
		void UpdateScreen(TRect &); // use this function to wingBlit from buffer
											 // directly to the screen dc

		uint32 backgroundROP; //This is used for clearing the buffer.

		TRect clientRect; // Derived classes can use this

		virtual void InitPalette()  {}

		virtual char *GetClassName()  {return "BitmapAnimatorWindow";}
		virtual void GetWindowClass(WNDCLASS &);

		virtual void SetupWindow();
      virtual void CleanupWindow();
		virtual void Paint(TDC &, bool, TRect &);

		// Message Handlers
		void EvPaletteChanged(HWND);
		bool EvQueryNewPalette();

};


#endif  //  #if !defined(__ULU_ANIMATE_H)

