//--
//--	spritwin.h
//--
//--	SpriteWindow Class Header File derived from TBitmapAnimatorWindow
//--
//--  This is where the action is.  It inherits Frame window functionality
//    and a WinG buffer from TBitmapAnimatorWindow.  It uses the Sprite class
//    to build a TArray of sprites, then move them around on the screen.
//
//    All I am using is one DIB that contains 6 animation cells.  I create a
//    container of sprites, assigning a random cell to each sprite.  I also
//    assign a random velocity to each.  Then I just move them around
//--


#if !defined(__ULU_SPRITEWIND_H)
#define __ULU_SPRITEWIND_H


// Make sure we have definitions for all types we use

#include <owl\module.h>
#include <owl\point.h>
#include <owl\gdiobjec.h>
#include <owl\window.h>
#include <classlib\arrays.h>
#pragma hdrstop

#include "animwind.h"
#include "sprite.h"

#define MAX_NUMB_DIBS (20)

typedef TArray<Sprite> Sprites;
typedef TArrayIterator<Sprite> SpriteIterator;

typedef TArray<TRect> RectList;
typedef TArrayIterator<TRect> RectIterator;

class SpriteWindow : public TBitmapAnimatorWindow
{


	public:
		SpriteWindow(TWindow *, const char far * = 0);
		virtual ~SpriteWindow();

	protected:

		// Because I am using many small sprites and they are all moving,
		RectList *dirtyRects; // used to consolidate the dirty rects
		Sprites *sprites; // pointer to TArray of Sprite
		int numbSprites; // Use this to track the number of sprites in the
							 // TArray container. It saves a function call?

		TDib *spriteDibs[MAX_NUMB_DIBS]; // load this with your sprite DIBs
		int numbDibs; // used to free the Dibs

		// Background stuff
		TBitmap *pBkgndBitmap;
		TMemoryDC *pBkgndDC;  // Holds my background DIB
		TRect BkgndRect; // Holds the loc of the background to enable clipping

		bool cont;   // This flag is used to break out of the animation loop

		void BuildSpriteList(); // Initialize the sprites

		void DrawBackground(TRect &); // Used to blit the background bitmap
												//to the WinG buffer

		void AnimLoop(); // This is the animation driver loop

		void TransformSprites(); // restore the background under the sprite, then
										 // change the sprites location

		void UpdateSprites(); // draw each sprite to the buffer

		// TBitmapAnimatorWindow overrides
		void SetupWindow();
		void InitPalette();
		bool CanClose();
		virtual void CleanupWindow();
		// Message Handlers
		void EvLButtonDown(uint, TPoint &); //Turn animation on
		void EvRButtonDown(uint, TPoint &);  // Turn animation off
		void EvKillFocus(HWND);  //  turn animation off

	DECLARE_RESPONSE_TABLE(SpriteWindow);
};




#endif  //  #if !defined(__ULU_SPRITEWIND_H)
